//------------------------------------------------------------
// Copyright (c) Microsoft Corporation.  All rights reserved.
//------------------------------------------------------------

using System;

using Microsoft.IdentityServer.Web;
using Microsoft.IdentityServer.Web.UI;
using com.swivelsecure.pinsafe;

/// <summary>
/// Attempts to authenticate the user via HTTP Forms Authentication.
/// </summary>
public partial class FormsSignIn : FormsLoginPage
{
    protected void Page_Load( object sender, EventArgs e ) {
        PINpad.PINField = OTC;
    }

    protected void HandleError( string message )
    {
        ErrorTextLabel.Visible = true;
        ErrorTextLabel.Text = Resources.CommonResources.IncorrectUsernameText;
    }

    protected bool ValidateOTP (string username, string passcode)
    {
        bool result=false;
        PINsafeClient client = new PINsafeClient();
       string otpResult= client.Login(username, string.Empty, passcode, DateTime.Now.AddMinutes(10));
        if (string.IsNullOrEmpty(otpResult))
        {
            result=false;
            ErrorTextLabel.Visible = true;
                ErrorTextLabel.Text="Invalid OTC";
        }
        else
        {
            ErrorTextLabel.Text = string.Empty;
            result = true;
        }
    return result;
    }

    protected void SubmitButton_Click( object sender, EventArgs e )
    {
        if (ValidateOTP(UsernameTextBox.Text,OTC.Text))
        {
            try
            {
                SignIn(UsernameTextBox.Text, PasswordTextBox.Text);
            }
            catch (AuthenticationFailedException ex)
            {
                HandleError(ex.Message);
            }
        }
    }

    protected void UsernameTextBox_TextChanged(object sender, EventArgs e) {
        PINpad.Username = UsernameTextBox.Text;
    }



    
    
}
